==> ui-react-1.1.461.tgz: package/esm/TableBody/TableBody.js <==
import _extends from "@babel/runtime/helpers/extends";
import _objectWithoutProperties from "@babel/runtime/helpers/objectWithoutProperties";
import _defineProperty from "@babel/runtime/helpers/defineProperty";
const _excluded = ["tonal", "color", "size", "Component", "className", "children"];
function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); enumerableOnly && (symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; })), keys.push.apply(keys, symbols); } return keys; }
function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = null != arguments[i] ? arguments[i] : {}; i % 2 ? ownKeys(Object(source), !0).forEach(function (key) { _defineProperty(target, key, source[key]); }) : Object.getOwnPropertyDescriptors ? Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)) : ownKeys(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } return target; }
import React from 'react';
import { classNames, style as styleMethod, useAmauiTheme } from '@amaui/style-react';
import SurfaceElement from '../Surface';
import { staticClassName } from '../utils';
const useStyle = styleMethod(theme => ({
  root: {
    display: 'table-row-group',
    background: 'inherit',
    '& .amaui-TableRow-root:last-child hr': {
      display: 'none'
    }
  }
}), {
  name: 'amaui-TableBody'
});
const TableBody = /*#__PURE__*/React.forwardRef((props_, ref) => {
  const theme = useAmauiTheme();
  const props = React.useMemo(() => _objectSpread(_objectSpread(_objectSpread({}, theme?.ui?.elements?.all?.props?.default), theme?.ui?.elements?.amauiTableBody?.props?.default), props_), [props_]);
  const Surface = React.useMemo(() => theme?.elements?.Surface || SurfaceElement, [theme]);
  const {
      tonal = true,
      color = 'themed',
      size = 'regular',
      Component = 'tbody',
      className,
      children
    } = props,
    other = _objectWithoutProperties(props, _excluded);
  const {
    classes
  } = useStyle();
  return /*#__PURE__*/React.createElement(Surface, _extends({
    ref: ref,
    tonal: tonal,
    color: color,
    role: "rowgroup",
    Component: Component,
    className: classNames([staticClassName('TableBody', theme) && [`amaui-TableBody-root`, `amaui-TableBody-size-${size}`], className, classes.root])
  }, other), React.Children.toArray(children).map(item => /*#__PURE__*/React.cloneElement(item, {
    tonal: item.props.tonal !== undefined ? item.props.tonal : tonal,
    color: item.props.color !== undefined ? item.props.color : color,
    size: item.props.size !== undefined ? item.props.size : size,
    position: 'body'
  })));
});
TableBody.displayName = 'amaui-TableBody';
export default TableBody;

==> ui-react-1.1.846.tgz: package/esm/TableBody/TableBody.js <==
import _extends from "@babel/runtime/helpers/extends";
import _objectWithoutProperties from "@babel/runtime/helpers/objectWithoutProperties";
import _defineProperty from "@babel/runtime/helpers/defineProperty";
const _excluded = ["tonal", "color", "size", "loading", "Component", "className", "children"];
function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); enumerableOnly && (symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; })), keys.push.apply(keys, symbols); } return keys; }
function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = null != arguments[i] ? arguments[i] : {}; i % 2 ? ownKeys(Object(source), !0).forEach(function (key) { _defineProperty(target, key, source[key]); }) : Object.getOwnPropertyDescriptors ? Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)) : ownKeys(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } return target; }
import React from 'react';
import { classNames, style as styleMethod, useAmauiTheme } from '@amaui/style-react';
import SurfaceElement from '../Surface';
import { staticClassName } from '../utils';
const useStyle = styleMethod(theme => ({
  root: {
    display: 'table-row-group',
    background: 'inherit',
    transition: theme.methods.transitions.make('opacity'),
    '& .amaui-TableRow-root:last-child hr': {
      display: 'none'
    },
    '& .amaui-TableCell-root': {
      wordBreak: 'normal'
    }
  },
  loading: {
    opacity: 0.4,
    pointerEvents: 'none'
  }
}), {
  name: 'amaui-TableBody'
});
const TableBody = /*#__PURE__*/React.forwardRef((props_, ref) => {
  const theme = useAmauiTheme();
  const props = React.useMemo(() => _objectSpread(_objectSpread(_objectSpread({}, theme?.ui?.elements?.all?.props?.default), theme?.ui?.elements?.amauiTableBody?.props?.default), props_), [props_]);
  const Surface = React.useMemo(() => theme?.elements?.Surface || SurfaceElement, [theme]);
  const {
      tonal = true,
      color = 'themed',
      size = 'regular',
      loading,
      Component = 'tbody',
      className,
      children: children_
    } = props,
    other = _objectWithoutProperties(props, _excluded);
  const {
    classes
  } = useStyle();
  const [children, setChildren] = React.useState(children_);
  React.useEffect(() => {
    if (!loading) {
      if (children_ !== children) setChildren(children_);
    }
  }, [loading, children_]);
  return /*#__PURE__*/React.createElement(Surface, _extends({
    ref: ref,
    tonal: tonal,
    color: color,
    role: "rowgroup",
    Component: Component,
    className: classNames([staticClassName('TableBody', theme) && [`amaui-TableBody-root`, `amaui-TableBody-size-${size}`], className, classes.root, loading && classes.loading])
  }, other), React.Children.toArray(children).map(item => /*#__PURE__*/React.cloneElement(item, {
    tonal: item.props.tonal !== undefined ? item.props.tonal : tonal,
    color: item.props.color !== undefined ? item.props.color : color,
    size: item.props.size !== undefined ? item.props.size : size,
    position: 'body'
  })));
});
TableBody.displayName = 'amaui-TableBody';
export default TableBody;
